 /********************************************************************/
 /*                                                                  */
 /*      Module:        PL/I Task Data Area (TDA)                    */
 /*      Version:       1.0                                          */
 /*      Date:          Jun, 2004                                    */
 /*      Author:        Peter Flass                                  */
 /*                                                                  */
 /*      Function:      TDA contains data describing one PL/I task.  */
 /*                                                                  */
 /*      Length:        96 bytes ('60'x).                            */
 /*                                                                  */
 /*      Where held:    Heap Storage.                                */
 /*                                                                  */
 /*      Pointed to by: Entry in 'GBL' points to the TDA for the     */
 /*                     major task.  TDAs are chained by             */
 /*                     attaching_task<->attached_task and in        */
 /*                     a global chain.                              */
 /*                                                                  */
 /*      Created by:    The TDA for the major task is created at     */
 /*                     startup.  Other TDAs are dynamically         */
 /*                     created by CALL statements with the TASK     */
 /*                     option.  New tasks are added to the front    */
 /*                     of the task chain, therefore the TDA for     */
 /*                     the major task will always be the last on    */
 /*                     the chain.                                   */
 /*                                                                  */
 /*      Deleted by:    Task termination.                            */
 /*                                                                  */
 /*      Dependencies:                                               */
 /*                     This must agree with the assembler version   */
 /*                     'tda.inc' used in 'init' and the storage     */
 /*                     reserved in 'plistart'.                      */
 /*                                                                  */
 /*      To Do:                                                      */
 /*                                                                  */
 /*      Modifications:                                              */
 /*                                                                  */
 /********************************************************************/

 dcl   1 TDA                 aligned based,
         5 TDA_next          ptr,           /* addr(next_TDA)   '00'x*/
         5 fily /* ? */      char(4),       /* unused           '04'x*/
         5 TDA_child         ptr,           /* addr(first_child)'08'x*/
         5 filx /* ? */      char(4),       /* unused           '0C'x*/
         5 TDA_parent        ptr,           /* addr(parent)     '10'x*/
         5 TDA_TID           fixed bin(31), /* Thread ID        '14'x*/
         5 TDA_priority      fixed bin(31), /* Thread Priority  '18'x*/
         5 TDA_alloc_count   fixed bin(31), /* 'Count' at attach'1C'x*/
         5 TDA_event         ptr,           /* addr(event_var)  '20'x*/
           /* Task? */
         5 fil0              char(8),       /* reserved         '24'x*/
         5 fil1              unaligned,     /*                  '2C'x*/
           10 TDA_flags      bit(8),        /* Thread Flags     '2C'x*/
             /* 1... .... Major Task thread ('80'bx) ( 1)            */
           10 fil2           char(1),       /* (alignment)      '2D'x*/
           10 TDA_level      fixed bin(15), /* Task depth       '2E'x*/
         5 TDA_ctl           ptr,           /* CTL stg chain    '30'x*/
         5 fil3              char(44),      /* (future use)     '34'x*/
         5 TDA_end           char(0);       /* End address      '60'x*/

